@@ -82,10 +82,11 @@ HEAT_BIN_DIR=$(dirname $(which heat-manage))
 $HEAT_BIN_DIR/heat-manage --config-file $HEAT_CONF db_sync || die $LINENO "DB sync error"
 
 # Start Heat
-start_heat_with_plugin
+start_heat
 
 # Don't succeed unless the services come up
-ensure_services_started heat-api heat-engine heat-api-cloudwatch heat-api-cfn
+# Truncating some service names to 11 characters
+ensure_services_started heat-api heat-engine heat-api-cl heat-api-cf
 
 set +o xtrace
 echo "*********************************************************************"
