@@ -29,9 +29,6 @@ from oslo_utils import importutils
 from heat.common import context
 from heat.common import exception
 from heat.common.i18n import _
-from heat.common.i18n import _LE
-from heat.common.i18n import _LW
-from heat.common import password_gen
 
 LOG = logging.getLogger('heat.engine.clients.keystoneclient')
 
@@ -97,7 +94,7 @@ class KsClientWrapper(object):
         self.domain_admin_user = cfg.CONF.stack_domain_admin
         self.domain_admin_password = cfg.CONF.stack_domain_admin_password
 
-        LOG.debug('Using stack domain %s' % self.stack_domain)
+        LOG.debug('Using stack domain %s', self.stack_domain)
 
     @property
     def context(self):
@@ -141,7 +138,7 @@ class KsClientWrapper(object):
             try:
                 auth.get_token(self.session)
             except ks_exception.Unauthorized:
-                LOG.error(_LE("Domain admin client authentication failed"))
+                LOG.error("Domain admin client authentication failed")
                 raise exception.AuthorizationFailure()
 
             self._domain_admin_auth = auth
@@ -168,17 +165,17 @@ class KsClientWrapper(object):
             try:
                 auth_ref = self.context.auth_plugin.get_access(self.session)
             except ks_exception.Unauthorized:
-                LOG.error(_LE("Keystone client authentication failed"))
+                LOG.error("Keystone client authentication failed")
                 raise exception.AuthorizationFailure()
 
             if self.context.trust_id:
                 # Sanity check
                 if not auth_ref.trust_scoped:
-                    LOG.error(_LE("trust token re-scoping failed!"))
+                    LOG.error("trust token re-scoping failed!")
                     raise exception.AuthorizationFailure()
                 # Sanity check that impersonation is effective
                 if self.context.trustor_user_id != auth_ref.user_id:
-                    LOG.error(_LE("Trust impersonation failed"))
+                    LOG.error("Trust impersonation failed")
                     raise exception.AuthorizationFailure()
 
         return client
@@ -203,7 +200,7 @@ class KsClientWrapper(object):
             trustee_user_id = self.context.trusts_auth_plugin.get_user_id(
                 self.session)
         except ks_exception.Unauthorized:
-            LOG.error(_LE("Domain admin client authentication failed"))
+            LOG.error("Domain admin client authentication failed")
             raise exception.AuthorizationFailure()
 
         trustor_user_id = self.context.auth_plugin.get_user_id(self.session)
@@ -241,11 +238,11 @@ class KsClientWrapper(object):
             pass
 
     def _get_username(self, username):
-        if(len(username) > 64):
-            LOG.warning(_LW("Truncating the username %s to the last 64 "
-                            "characters."), username)
-        # get the last 64 characters of the username
-        return username[-64:]
+        if(len(username) > 255):
+            LOG.warning("Truncating the username %s to the last 255 "
+                        "characters.", username)
+        # get the last 255 characters of the username
+        return username[-255:]
 
     def create_stack_user(self, username, password=''):
         """Create a user defined as part of a stack.
@@ -269,15 +266,15 @@ class KsClientWrapper(object):
                 name=self._get_username(username), password=password,
                 default_project=self.context.tenant_id)
             # Add user to heat_stack_user_role
-            LOG.debug("Adding user %(user)s to role %(role)s" % {
-                      'user': user.id, 'role': role_id})
+            LOG.debug("Adding user %(user)s to role %(role)s",
+                      {'user': user.id, 'role': role_id})
             self.client.roles.grant(role=role_id, user=user.id,
                                     project=self.context.tenant_id)
         else:
-            LOG.error(_LE("Failed to add user %(user)s to role %(role)s, "
-                          "check role exists!"), {
-                      'user': username,
-                      'role': cfg.CONF.heat_stack_user_role})
+            LOG.error("Failed to add user %(user)s to role %(role)s, "
+                      "check role exists!",
+                      {'user': username,
+                       'role': cfg.CONF.heat_stack_user_role})
             raise exception.Error(_("Can't find role %s")
                                   % cfg.CONF.heat_stack_user_role)
 
@@ -332,13 +329,13 @@ class KsClientWrapper(object):
                 name=self._get_username(username), password=password,
                 default_project=project_id, domain=self.stack_domain_id)
             # Add to stack user role
-            LOG.debug("Adding user %(user)s to role %(role)s" % {
-                      'user': user.id, 'role': role_id})
+            LOG.debug("Adding user %(user)s to role %(role)s",
+                      {'user': user.id, 'role': role_id})
             self.domain_admin_client.roles.grant(role=role_id, user=user.id,
                                                  project=project_id)
         else:
-            LOG.error(_LE("Failed to add user %(user)s to role %(role)s, "
-                          "check role exists!"),
+            LOG.error("Failed to add user %(user)s to role %(role)s, "
+                      "check role exists!",
                       {'user': username,
                        'role': cfg.CONF.heat_stack_user_role})
             raise exception.Error(_("Can't find role %s")
@@ -352,7 +349,7 @@ class KsClientWrapper(object):
             try:
                 access = self.domain_admin_auth.get_access(self.session)
             except ks_exception.Unauthorized:
-                LOG.error(_LE("Keystone client authentication failed"))
+                LOG.error("Keystone client authentication failed")
                 raise exception.AuthorizationFailure()
 
             self._stack_domain_id = access.domain_id
@@ -418,12 +415,12 @@ class KsClientWrapper(object):
         except ks_exception.NotFound:
             return
         except ks_exception.Forbidden:
-            LOG.warning(_LW('Unable to get details for project %s, '
-                            'not deleting'), project_id)
+            LOG.warning('Unable to get details for project %s, '
+                        'not deleting', project_id)
             return
 
         if project.domain_id != self.stack_domain_id:
-            LOG.warning(_LW('Not deleting non heat-domain project'))
+            LOG.warning('Not deleting non heat-domain project')
             return
 
         try:
@@ -480,7 +477,7 @@ class KsClientWrapper(object):
         user_id = user_id or self.context.get_access(self.session).user_id
         project_id = self.context.tenant_id
         data_blob = {'access': uuid.uuid4().hex,
-                     'secret': password_gen.generate_openstack_password()}
+                     'secret': uuid.uuid4().hex}
         ec2_creds = self.client.credentials.create(
             user=user_id, type='ec2', blob=jsonutils.dumps(data_blob),
             project=project_id)
@@ -499,7 +496,7 @@ class KsClientWrapper(object):
             # files which lack domain configuration
             return self.create_ec2_keypair(user_id)
         data_blob = {'access': uuid.uuid4().hex,
-                     'secret': password_gen.generate_openstack_password()}
+                     'secret': uuid.uuid4().hex}
         creds = self.domain_admin_client.credentials.create(
             user=user_id, type='ec2', blob=jsonutils.dumps(data_blob),
             project=project_id)
@@ -541,20 +538,6 @@ class KsClientWrapper(object):
         self._check_stack_domain_user(user_id, project_id, 'enable')
         self.domain_admin_client.users.update(user=user_id, enabled=True)
 
-    def url_for(self, **kwargs):
-        default_region_name = (self.context.region_name or
-                               cfg.CONF.region_name_for_services)
-        kwargs.setdefault('region_name', default_region_name)
-        return self.context.auth_plugin.get_endpoint(self.session, **kwargs)
-
-    @property
-    def auth_token(self):
-        return self.context.auth_plugin.get_token(self.session)
-
-    @property
-    def auth_ref(self):
-        return self.context.auth_plugin.get_access(self.session)
-
 
 class KeystoneClient(object):
     """Keystone Auth Client.
