@@ -18,8 +18,6 @@ import six
 from heat.common import exception
 from heat.common import grouputils
 from heat.common.i18n import _
-from heat.common.i18n import _LE
-from heat.common.i18n import _LI
 from heat.engine import attributes
 from heat.engine import constraints
 from heat.engine import function
@@ -251,6 +249,13 @@ class AutoScalingGroup(cooldown.CooldownMixin, instgrp.InstanceGroup):
                                               min_adjustment_step,
                                               lower, upper)
 
+    def resize(self, capacity):
+        try:
+            super(AutoScalingGroup, self).resize(capacity)
+        finally:
+            # allow InstanceList to be re-resolved
+            self.clear_stored_attributes()
+
     def handle_update(self, json_snippet, tmpl_diff, prop_diff):
         """Updates self.properties, if Properties has changed.
 
@@ -282,8 +287,8 @@ class AutoScalingGroup(cooldown.CooldownMixin, instgrp.InstanceGroup):
                min_adjustment_step=None):
         """Adjust the size of the scaling group if the cooldown permits."""
         if self.status != self.COMPLETE:
-            LOG.info(_LI("%s NOT performing scaling adjustment, "
-                         "when status is not COMPLETE") % self.name)
+            LOG.info("%s NOT performing scaling adjustment, "
+                     "when status is not COMPLETE", self.name)
             raise resource.NoActionRequired
 
         capacity = grouputils.get_size(self)
@@ -291,8 +296,8 @@ class AutoScalingGroup(cooldown.CooldownMixin, instgrp.InstanceGroup):
                                               adjustment_type,
                                               min_adjustment_step)
         if new_capacity == capacity:
-            LOG.info(_LI("%s NOT performing scaling adjustment, "
-                         "as there is no change in capacity.") % self.name)
+            LOG.info("%s NOT performing scaling adjustment, "
+                     "as there is no change in capacity.", self.name)
             raise resource.NoActionRequired
 
         self._check_scaling_allowed()
@@ -322,7 +327,7 @@ class AutoScalingGroup(cooldown.CooldownMixin, instgrp.InstanceGroup):
                                       })
                         notification.send(**notif)
                     except Exception:
-                        LOG.exception(_LE('Failed sending error notification'))
+                        LOG.exception('Failed sending error notification')
             else:
                 size_changed = True
                 notif.update({
@@ -333,8 +338,8 @@ class AutoScalingGroup(cooldown.CooldownMixin, instgrp.InstanceGroup):
                 })
                 notification.send(**notif)
         except Exception:
-            LOG.error(_LE("Error in performing scaling adjustment for"
-                          "group %s.") % self.name)
+            LOG.error("Error in performing scaling adjustment for "
+                      "group %s.", self.name)
             raise
         finally:
             self._finished_scaling("%s : %s" % (adjustment_type, adjustment),
@@ -392,16 +397,6 @@ class AutoScalingGroup(cooldown.CooldownMixin, instgrp.InstanceGroup):
 
         super(AutoScalingGroup, self).validate()
 
-    def _resolve_attribute(self, name):
-        """Resolves the resource's attributes.
-
-        heat extension: "InstanceList" returns comma delimited list of server
-        ip addresses.
-        """
-        if name == self.INSTANCE_LIST:
-            return u','.join(inst.FnGetAtt('PublicIp')
-                             for inst in grouputils.get_members(self)) or None
-
     def child_template(self):
         if self.properties[self.DESIRED_CAPACITY]:
             num_instances = self.properties[self.DESIRED_CAPACITY]
