@@ -209,11 +209,9 @@ class SoftwareDeployment(signal_responder.SignalResponder):
         return props
 
     def _delete_derived_config(self, derived_config_id):
-        try:
+        with self.rpc_client().ignore_error_by_name('NotFound'):
             self.rpc_client().delete_software_config(
                 self.context, derived_config_id)
-        except Exception as ex:
-            self.rpc_client().ignore_error_named(ex, 'NotFound')
 
     def _create_derived_config(self, action, source_config):
 
@@ -466,10 +464,8 @@ class SoftwareDeployment(signal_responder.SignalResponder):
         return self._check_complete()
 
     def handle_delete(self):
-        try:
+        with self.rpc_client().ignore_error_by_name('NotFound'):
             return self._handle_action(self.DELETE)
-        except Exception as ex:
-            self.rpc_client().ignore_error_named(ex, 'NotFound')
 
     def check_delete_complete(self, sd=None):
         if not sd or not self._server_exists(sd) or self._check_complete():
@@ -477,21 +473,19 @@ class SoftwareDeployment(signal_responder.SignalResponder):
             return True
 
     def _delete_resource(self):
-        self._delete_signals()
-        self._delete_user()
-
         derived_config_id = None
         if self.resource_id is not None:
-            try:
+            with self.rpc_client().ignore_error_by_name('NotFound'):
                 derived_config_id = self._get_derived_config_id()
                 self.rpc_client().delete_software_deployment(
                     self.context, self.resource_id)
-            except Exception as ex:
-                self.rpc_client().ignore_error_named(ex, 'NotFound')
 
         if derived_config_id:
             self._delete_derived_config(derived_config_id)
 
+        self._delete_signals()
+        self._delete_user()
+
     def handle_suspend(self):
         return self._handle_action(self.SUSPEND)
 
@@ -513,6 +507,38 @@ class SoftwareDeployment(signal_responder.SignalResponder):
             self.context, self.resource_id, details,
             timeutils.utcnow().isoformat())
 
+    def _handle_cancel(self):
+        if self.resource_id is None:
+            return
+
+        sd = self.rpc_client().show_software_deployment(
+            self.context, self.resource_id)
+
+        if sd is None:
+            return
+
+        status = sd[rpc_api.SOFTWARE_DEPLOYMENT_STATUS]
+        if status == SoftwareDeployment.IN_PROGRESS:
+            self.rpc_client().update_software_deployment(
+                self.context, self.resource_id,
+                status=SoftwareDeployment.FAILED,
+                status_reason=_('Deployment cancelled.'))
+
+    def handle_create_cancel(self, cookie):
+        self._handle_cancel()
+
+    def handle_update_cancel(self, cookie):
+        self._handle_cancel()
+
+    def handle_delete_cancel(self, cookie):
+        self._handle_cancel()
+
+    def handle_suspend_cancel(self, cookie):
+        self._handle_cancel()
+
+    def handle_resume_cancel(self, cookie):
+        self._handle_cancel()
+
     def get_attribute(self, key, *path):
         """Resource attributes map to deployment outputs values."""
         sd = self.rpc_client().show_software_deployment(
@@ -663,7 +689,8 @@ class SoftwareDeploymentGroup(resource_group.ResourceGroup):
     def get_size(self):
         return len(self.properties[self.SERVERS])
 
-    def _resource_names(self, size=None):
+    def _resource_names(self, size=None,
+                        update_rsrc_data=True):
         candidates = self.properties[self.SERVERS]
         if size is None:
             return iter(candidates)
