@@ -27,7 +27,6 @@ import tenacity
 from heat.common import crypt
 from heat.common import exception
 from heat.common.i18n import _
-from heat.common.i18n import _LE
 from heat.db.sqlalchemy import api as db_api
 from heat.objects import base as heat_base
 from heat.objects import fields as heat_fields
@@ -78,6 +77,9 @@ class Resource(
         'status': fields.StringField(nullable=True),
         'status_reason': fields.StringField(nullable=True),
         'action': fields.StringField(nullable=True),
+        'attr_data': fields.ObjectField(
+            rpd.ResourcePropertiesData, nullable=True),
+        'attr_data_id': fields.IntegerField(nullable=True),
         'rsrc_metadata': heat_fields.JsonField(nullable=True),
         'data': fields.ListOfObjectsField(
             resource_data.ResourceData,
@@ -98,15 +100,18 @@ class Resource(
     }
 
     @staticmethod
-    def _from_db_object(resource, context, db_resource):
+    def _from_db_object(resource, context, db_resource, only_fields=None):
         if db_resource is None:
             return None
         for field in resource.fields:
+            if (only_fields is not None and field not in only_fields
+                    and field != 'id'):
+                continue
             if field == 'data':
                 resource['data'] = [resource_data.ResourceData._from_db_object(
                     resource_data.ResourceData(context), resd
                 ) for resd in db_resource.data]
-            else:
+            elif field != 'attr_data':
                 resource[field] = db_resource[field]
 
         if db_resource['rsrc_prop_data'] is not None:
@@ -117,12 +122,12 @@ class Resource(
             resource._properties_data = resource['rsrc_prop_data'].data
             if db_resource['properties_data']:
                 LOG.error(
-                    _LE('Unexpected condition where resource.rsrc_prop_data '
-                        'and resource.properties_data are both not null. '
-                        'rsrc_prop_data.id: %(rsrc_prop_data_id)s ,'
-                        'resource id: %(res_id)s')
-                    % {'rsrc_prop_data_id': resource['rsrc_prop_data'].id,
-                       'res_id': resource['id']})
+                    'Unexpected condition where resource.rsrc_prop_data '
+                    'and resource.properties_data are both not null. '
+                    'rsrc_prop_data.id: %(rsrc_prop_data_id)s, '
+                    'resource id: %(res_id)s',
+                    {'rsrc_prop_data_id': resource['rsrc_prop_data'].id,
+                     'res_id': resource['id']})
         elif db_resource['properties_data']:  # legacy field
             if db_resource['properties_data_encrypted']:
                 decrypted_data = crypt.decrypted_dict(
@@ -131,21 +136,38 @@ class Resource(
             else:
                 resource._properties_data = db_resource['properties_data']
         else:
-            resource._properties_data = {}
+            resource._properties_data = None
+
+        if db_resource['attr_data'] is not None:
+            resource._attr_data = rpd.ResourcePropertiesData._from_db_object(
+                rpd.ResourcePropertiesData(context), context,
+                db_resource['attr_data']).data
+        else:
+            resource._attr_data = None
 
         resource._context = context
         resource.obj_reset_changes()
         return resource
 
+    @property
+    def attr_data(self):
+        return self._attr_data
+
     @property
     def properties_data(self):
         return self._properties_data
 
     @classmethod
-    def get_obj(cls, context, resource_id, refresh=False):
+    def get_obj(cls, context, resource_id, refresh=False, fields=None):
+        if fields is None or 'data' in fields:
+            refresh_data = refresh
+        else:
+            refresh_data = False
         resource_db = db_api.resource_get(context, resource_id,
-                                          refresh=refresh)
-        return cls._from_db_object(cls(context), context, resource_db)
+                                          refresh=refresh,
+                                          refresh_data=refresh_data)
+        return cls._from_db_object(cls(context), context, resource_db,
+                                   only_fields=fields)
 
     @classmethod
     def get_all(cls, context):
@@ -168,6 +190,10 @@ class Resource(
     def delete(cls, context, resource_id):
         db_api.resource_delete(context, resource_id)
 
+    @classmethod
+    def attr_data_delete(cls, context, resource_id, attr_id):
+        db_api.resource_attr_data_delete(context, resource_id, attr_id)
+
     @classmethod
     def exchange_stacks(cls, context, resource_id1, resource_id2):
         return db_api.resource_exchange_stacks(
@@ -253,6 +279,24 @@ class Resource(
                                       atomic_key=atomic_key,
                                       expected_engine_id=expected_engine_id)
 
+    @classmethod
+    def select_and_update_by_id(cls, context, resource_id,
+                                values, expected_engine_id=None,
+                                atomic_key=0):
+        return db_api.resource_update(context, resource_id, values,
+                                      atomic_key=atomic_key,
+                                      expected_engine_id=expected_engine_id)
+
+    @classmethod
+    def store_attributes(cls, context, resource_id, atomic_key,
+                         attr_data, attr_id):
+        attr_id = rpd.ResourcePropertiesData.create_or_update(
+            context, attr_data, attr_id).id
+        if db_api.resource_attr_id_set(
+                context, resource_id, atomic_key, attr_id):
+            return attr_id
+        return None
+
     def refresh(self):
         resource_db = db_api.resource_get(self._context, self.id, refresh=True)
         return self.__class__._from_db_object(
@@ -274,3 +318,6 @@ class Resource(
             if not rows_updated:
                 action = _('metadata setting for resource %s') % self.name
                 raise exception.ConcurrentTransaction(action=action)
+            return True
+        else:
+            return False
