@@ -19,8 +19,9 @@ import webob
 from heat.common import exception
 from heat.common.i18n import _
 from heat.common import template_format
+from heat.common import urlfetch
 from heat.engine.clients.os import glance
-from heat.engine.clients.os import nova
+from heat.engine import dependencies
 from heat.engine import environment
 from heat.engine.hot import template as hot_tmpl
 from heat.engine import resources
@@ -898,9 +899,24 @@ outputs:
     value: {get_attr: [[random_str, value]]}
 '''
 
+test_template_circular_reference = '''
+heat_template_version: 2013-05-23
+
+resources:
+  res1:
+    type: OS::Heat::None
+    depends_on: res3
+  res2:
+    type: OS::Heat::None
+    depends_on: res1
+  res3:
+    type: OS::Heat::None
+    depends_on: res2
+'''
+
 
 test_template_external_rsrc = '''
-heat_template_version: ocata
+heat_template_version: pike
 
 resources:
   random_str:
@@ -924,17 +940,13 @@ class ValidateTest(common.HeatTestCase):
         self.addCleanup(self.mock_isa.stop)
         self.engine = service.EngineService('a', 't')
 
-    def _mock_get_image_id_success(self, imageId_input, imageId):
-        self.m.StubOutWithMock(glance.GlanceClientPlugin,
-                               'find_image_by_name_or_id')
-        glance.GlanceClientPlugin.find_image_by_name_or_id(
-            imageId_input).MultipleTimes().AndReturn(imageId)
+    def _mock_get_image_id_success(self, imageId):
+        self.patchobject(glance.GlanceClientPlugin, 'find_image_by_name_or_id',
+                         return_value=imageId)
 
-    def _mock_get_image_id_fail(self, image_id, exp):
-        self.m.StubOutWithMock(glance.GlanceClientPlugin,
-                               'find_image_by_name_or_id')
-        glance.GlanceClientPlugin.find_image_by_name_or_id(
-            image_id).AndRaise(exp)
+    def _mock_get_image_id_fail(self, exp):
+        self.patchobject(glance.GlanceClientPlugin, 'find_image_by_name_or_id',
+                         side_effect=exp)
 
     def test_validate_volumeattach_valid(self):
         t = template_format.parse(test_template_volumeattach % 'vdq')
@@ -1368,11 +1380,9 @@ class ValidateTest(common.HeatTestCase):
 
         self.stub_FlavorConstraint_validate()
         self.stub_ImageConstraint_validate()
-        self.m.ReplayAll()
 
         resource = stack['Instance']
         self.assertRaises(exception.StackValidationFailed, resource.validate)
-        self.m.VerifyAll()
 
     def test_unregistered_image(self):
         t = template_format.parse(test_template_image)
@@ -1382,19 +1392,15 @@ class ValidateTest(common.HeatTestCase):
 
         stack = parser.Stack(self.ctx, 'test_stack', template)
 
-        self._mock_get_image_id_fail('image_name',
-                                     exception.EntityNotFound(
-                                         entity='Image',
-                                         name='image_name'))
+        self._mock_get_image_id_fail(exception.EntityNotFound(
+                                     entity='Image',
+                                     name='image_name'))
         self.stub_KeypairConstraint_validate()
         self.stub_FlavorConstraint_validate()
-        self.m.ReplayAll()
 
         resource = stack['Instance']
         self.assertRaises(exception.StackValidationFailed, resource.validate)
 
-        self.m.VerifyAll()
-
     def test_duplicated_image(self):
         t = template_format.parse(test_template_image)
         template = tmpl.Template(t,
@@ -1403,66 +1409,56 @@ class ValidateTest(common.HeatTestCase):
 
         stack = parser.Stack(self.ctx, 'test_stack', template)
 
-        self._mock_get_image_id_fail('image_name',
-                                     exception.PhysicalResourceNameAmbiguity(
-                                         name='image_name'))
+        self._mock_get_image_id_fail(exception.PhysicalResourceNameAmbiguity(
+                                     name='image_name'))
 
         self.stub_KeypairConstraint_validate()
         self.stub_FlavorConstraint_validate()
-        self.m.ReplayAll()
 
         resource = stack['Instance']
         self.assertRaises(exception.StackValidationFailed,
                           resource.validate)
 
-        self.m.VerifyAll()
-
-    def test_invalid_security_groups_with_nics(self):
+    @mock.patch('heat.engine.clients.os.nova.NovaClientPlugin._create')
+    def test_invalid_security_groups_with_nics(self, mock_create):
         t = template_format.parse(test_template_invalid_secgroups)
         template = tmpl.Template(t,
                                  env=environment.Environment(
                                      {'KeyName': 'test'}))
         stack = parser.Stack(self.ctx, 'test_stack', template)
 
-        self._mock_get_image_id_success('image_name', 'image_id')
+        self._mock_get_image_id_success('image_id')
 
-        self.m.StubOutWithMock(nova.NovaClientPlugin, '_create')
-        nova.NovaClientPlugin._create().AndReturn(self.fc)
-        self.m.ReplayAll()
+        mock_create.return_value = self.fc
 
         resource = stack['Instance']
         self.assertRaises(exception.ResourcePropertyConflict,
                           resource.validate)
-        self.m.VerifyAll()
 
-    def test_invalid_security_group_ids_with_nics(self):
+    @mock.patch('heat.engine.clients.os.nova.NovaClientPlugin._create')
+    def test_invalid_security_group_ids_with_nics(self, mock_create):
         t = template_format.parse(test_template_invalid_secgroupids)
         template = tmpl.Template(
             t, env=environment.Environment({'KeyName': 'test'}))
         stack = parser.Stack(self.ctx, 'test_stack', template)
 
-        self._mock_get_image_id_success('image_name', 'image_id')
+        self._mock_get_image_id_success('image_id')
 
-        self.m.StubOutWithMock(nova.NovaClientPlugin, '_create')
-        nova.NovaClientPlugin._create().AndReturn(self.fc)
-        self.m.ReplayAll()
+        mock_create.return_value = self.fc
 
         resource = stack['Instance']
         self.assertRaises(exception.ResourcePropertyConflict,
                           resource.validate)
-        self.m.VerifyAll()
 
-    def test_client_exception_from_glance_client(self):
+    @mock.patch('heat.engine.clients.os.glance.GlanceClientPlugin.client')
+    def test_client_exception_from_glance_client(self, mock_client):
         t = template_format.parse(test_template_glance_client_exception)
         template = tmpl.Template(t)
         stack = parser.Stack(self.ctx, 'test_stack', template)
-        self.m.StubOutWithMock(glance.GlanceClientPlugin, 'client')
-        glance.GlanceClientPlugin.client().AndReturn(self.gc)
+        mock_client.return_value = self.gc
         self.stub_FlavorConstraint_validate()
-        self.m.ReplayAll()
 
         self.assertRaises(exception.StackValidationFailed, stack.validate)
-        self.m.VerifyAll()
 
     def test_validate_unique_logical_name(self):
         t = template_format.parse(test_template_unique_logical_name)
@@ -1778,13 +1774,88 @@ class ValidateTest(common.HeatTestCase):
         self.assertIsInstance(res, webob.exc.HTTPBadRequest)
         self.assertEqual(ex.explanation, res.explanation)
 
+    def test_validate_parameter_group_output(self):
+        engine = service.EngineService('a', 't')
+        params = {
+            "resource_registry": {
+                "OS::Test::TestResource": "https://server.test/nested.template"
+            }
+        }
+        root_template_str = '''
+heat_template_version: 2015-10-15
+parameters:
+    test_root_param:
+        type: string
+parameter_groups:
+-   label: RootTest
+    parameters:
+    -   test_root_param
+resources:
+    Nested:
+        type: OS::Test::TestResource
+'''
+        nested_template_str = '''
+heat_template_version: 2015-10-15
+parameters:
+    test_param:
+        type: string
+parameter_groups:
+-   label: Test
+    parameters:
+    -   test_param
+'''
+        root_template = template_format.parse(root_template_str)
+
+        self.patchobject(urlfetch, 'get')
+        urlfetch.get.return_value = nested_template_str
+
+        res = dict(engine.validate_template(self.ctx, root_template,
+                                            params, show_nested=True))
+        expected = {
+            'Description': 'No description',
+            'ParameterGroups': [{
+                'label': 'RootTest',
+                'parameters': ['test_root_param']}],
+            'Parameters': {
+                'test_root_param': {
+                    'Description': '',
+                    'Label': 'test_root_param',
+                    'NoEcho': 'false',
+                    'Type': 'String'}},
+            'NestedParameters': {
+                'Nested': {
+                    'Description': 'No description',
+                    'ParameterGroups': [{
+                        'label': 'Test',
+                        'parameters': ['test_param']}],
+                    'Parameters': {
+                        'test_param': {
+                            'Description': '',
+                            'Label': 'test_param',
+                            'NoEcho': 'false',
+                            'Type': 'String'}},
+                    'Type': 'OS::Test::TestResource'}},
+        }
+        self.assertEqual(expected, res)
+
     def test_validate_allowed_external_rsrc(self):
         t = template_format.parse(test_template_external_rsrc)
         template = tmpl.Template(t)
         stack = parser.Stack(self.ctx, 'test_stack', template)
 
+        self.assertIsNone(stack.validate(validate_res_tmpl_only=True))
+
         with mock.patch(
             'heat.engine.resources.server_base.BaseServer._show_resource',
             return_value={'id': 'foobar'}
         ):
-            self.assertIsNone(stack.validate())
+            self.assertIsNone(stack.validate(validate_res_tmpl_only=False))
+
+    def test_validate_circular_reference(self):
+        t = template_format.parse(test_template_circular_reference)
+
+        exc = self.assertRaises(dispatcher.ExpectedException,
+                                self.engine.validate_template,
+                                self.ctx, t, {})
+        self.assertEqual(dependencies.CircularDependencyException,
+                         exc.exc_info[0])
