@@ -31,13 +31,14 @@ source $DEST/devstack/openrc demo demo
 # user creds
 iniset $conf_file heat_plugin username $OS_USERNAME
 iniset $conf_file heat_plugin password $OS_PASSWORD
-iniset $conf_file heat_plugin tenant_name $OS_PROJECT_NAME
+iniset $conf_file heat_plugin project_name $OS_PROJECT_NAME
 iniset $conf_file heat_plugin auth_url $OS_AUTH_URL
 iniset $conf_file heat_plugin user_domain_id $OS_USER_DOMAIN_ID
 iniset $conf_file heat_plugin project_domain_id $OS_PROJECT_DOMAIN_ID
 iniset $conf_file heat_plugin user_domain_name $OS_USER_DOMAIN_NAME
 iniset $conf_file heat_plugin project_domain_name $OS_PROJECT_DOMAIN_NAME
 iniset $conf_file heat_plugin region $OS_REGION_NAME
+iniset $conf_file heat_plugin auth_version $OS_IDENTITY_API_VERSION
 
 source $DEST/devstack/openrc admin admin
 iniset $conf_file heat_plugin admin_username $OS_USERNAME
@@ -50,17 +51,19 @@ iniset $conf_file heat_plugin minimal_instance_type m1.heat_micro
 openstack flavor create m1.heat_int --ram 512
 openstack flavor create m1.heat_micro --ram 128
 
-iniset $conf_file heat_plugin image_ref Fedora-Cloud-Base-27-1.6.x86_64
+iniset $conf_file heat_plugin image_ref Fedora-Cloud-Base-24-1.2.x86_64
 iniset $conf_file heat_plugin boot_config_env $DEST/heat-templates/hot/software-config/boot-config/test_image_env.yaml
 iniset $conf_file heat_plugin heat_config_notify_script $DEST/heat-templates/hot/software-config/elements/heat-config/bin/heat-config-notify
-iniset $conf_file heat_plugin minimal_image_ref cirros-0.3.4-x86_64-uec
+iniset $conf_file heat_plugin minimal_image_ref cirros-0.3.5-x86_64-disk
 
 # Skip test_cancel_update_server_with_port till bug #1607714 is fixed in nova
-iniset $conf_file heat_plugin skip_functional_test_list 'CancelUpdateTest.test_cancel_update_server_with_port'
+# Skip ReloadOnSighupTest. Most jobs now run with apache+uwsgi, so the test has no significance
+iniset $conf_file heat_plugin skip_functional_test_list 'CancelUpdateTest.test_cancel_update_server_with_port, ReloadOnSighupTest, StackSnapshotRestoreTest'
 
 # Add scenario tests to skip
 # VolumeBackupRestoreIntegrationTest skipped until failure rate can be reduced ref bug #1382300
 # test_server_signal_userdata_format_software_config is skipped untill bug #1651768 is resolved
-iniset $conf_file heat_plugin skip_scenario_test_list 'SoftwareConfigIntegrationTest, VolumeBackupRestoreIntegrationTest, ServerSignalIntegrationTest.test_server_signal_userdata_format_software_config'
+# StackSnapshotRestoreTest skipped until bug #1694371 is resolved
+iniset $conf_file heat_plugin skip_scenario_test_list 'SoftwareConfigIntegrationTest, VolumeBackupRestoreIntegrationTest'
 
 cat $conf_file
